#
# spec file for package python-oauth2client
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-oauth2client
Version:        4.1.2
Release:        lp152.4.3
Summary:        Pythob OAuth2 Client
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/google/oauth2client
Source0:        oauth2client-%{version}.tar.gz
Patch1:         oauth2client-init-django-settings.patch
Patch2:         o2c_reauth.patch
Requires:       python
Requires:       python-fasteners
Requires:       python-httplib2        >= 0.9.1
Requires:       python-keyring
Requires:       python-pyasn1          >= 0.1.7
Requires:       python-pyasn1-modules  >= 0.0.5
Requires:       python-pycrypto
Requires:       python-rsa             >= 3.1.4
Requires:       python-six             >= 1.6.1
%if 0%{?is_opensuse}
BuildRequires:  %{python_module Django >= 1.8}
%endif
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module fasteners}
BuildRequires:  %{python_module httplib2 >= 0.9.1}
BuildRequires:  %{python_module keyring}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module pyOpenSSL}
BuildRequires:  %{python_module pyasn1-modules >= 0.0.5}
BuildRequires:  %{python_module pycrypto}
BuildRequires:  %{python_module rsa >= 3.1.4}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.6.1}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Conflicts:      google-api-python-client  < 1.3.0
# Don't ask, we obviously have problems working together
Conflicts:      python-google-api-python-client  < 1.3.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
This is a Python library for accessing resources protected by OAuth 2.0.

%if 0%{?is_opensuse}
%package django
Summary:        Django extension
Group:          Development/Libraries/Python
PreReq:         python-oauth2client = %version
Requires:       python-Django >= 1.8

%description django
OAuth 2.0 utilities for Django.

Utilities for using OAuth 2.0 in conjunction with
the Django datastore.
%endif

%package flask
Summary:        Flask extension
Group:          Development/Libraries/Python
PreReq:         python-oauth2client = %version
Requires:       python-Flask

%description flask
Provides a Flask extension that makes using OAuth2 web server flow easier.
The extension includes views that handle the entire auth flow and a
``@required`` decorator to automatically ensure that user credentials are
available.

%package gce
Summary:        GCE extension
Group:          Development/Libraries/Python
PreReq:         python-oauth2client = %version

%description gce
Utilities for Google Compute Engine

Utilities for making it easier to use OAuth 2.0 on Google Compute Engine.

%python_subpackages

%prep
%setup -q -n oauth2client-%{version}
# remove extensions currently not packaged
rm -rf oauth2client/contrib/*appengine*
rm -f oauth2client/contrib/__pycache__/*appengine*
%if 0%{?is_opensuse}
%patch1
%else
# No Django on SLE
rm -rf oauth2client/contrib/django*
%endif
%patch2

%build
%python_build

%install
%python_install
# remove tests for extensions we do not build at the moment
rm -rf tests/contrib/appengine

%fdupes %{buildroot}%{_prefix}

%files %{python_files}
%defattr(-,root,root,-)
%doc README.md
%dir %{python_sitelib}/oauth2client
%dir %{python_sitelib}/oauth2client-%{version}-py%{py_ver}.egg-info
%exclude %{python_sitelib}/oauth2client/contrib/django*
%exclude %{python_sitelib}/oauth2client/contrib/flask*
%exclude %{python_sitelib}/oauth2client/contrib/__pycache__/flask*
%exclude %{python_sitelib}/oauth2client/contrib/gce*
%exclude %{python_sitelib}/oauth2client/contrib/__pycache__/gce*
%{python_sitelib}/oauth2client/*
%{python_sitelib}/oauth2client-%{version}-py%{py_ver}.egg-info/*

%files %{python_files flask}
%defattr(-,root,root,-)
%{python_sitelib}/oauth2client/contrib/flask*
%ifpython3
%{python_sitelib}/oauth2client/contrib/__pycache__/flask*
%endif

%if 0%{?is_opensuse}
%files %{python_files django}
%defattr(-,root,root,-)
%{python_sitelib}/oauth2client/contrib/django*
%endif

%files %{python_files gce}
%defattr(-,root,root,-)
%{python_sitelib}/oauth2client/contrib/gce*
%ifpython3
%{python_sitelib}/oauth2client/contrib/__pycache__/gce*
%endif

%if 0
%files %{python_files test}
%defattr(-,root,root,-)
%dir %{python_sitelib}/tests
%dir %{python_sitelib}/tests/oauth2client
%{python_sitelib}/tests/oauth2client/*
%endif

%changelog
* Thu Jun 14 2018 rjschwei@suse.com
- Do not build Django extension on SLES
* Sat Jul  8 2017 dmueller@suse.com
- remove tox dependency
* Sat Jul  1 2017 mc@suse.com
- update to version 4.1.2
  * New features:
  * Allow passing prompt='consent' via the flow_from_clientsecrets. (#717)
  * Allow customizing the GCE metadata service address via an env var. (#704)
  * Store original encoded and signed identity JWT in OAuth2Credentials. (#680)
  * Use jsonpickle in django contrib, if available. (#676)
  * Bug fixes:
  * Fix packaging issue had erroneously installed the test package. (#688)
  * Typo fixes. (#668, #697)
  * Remove b64 padding from PKCE values, per RFC7636. (#683)
  * Include LICENSE in Manifest.in. (#694)
  * Fix tests and CI. (#705, #712, #713)
  * Escape callback error code in flask_util. (#710)
- package python3 in singlespec
- remove o2c_hide-deprecation-warning.patch (upstream)
* Mon Jan 30 2017 rjschwei@suse.com
- Add o2c_hide-deprecation-warning.patch
- Add o2c_reauth.patch (bsc#1002895)
* Fri Oct 21 2016 arun@gmx.de
- update to version 4.0.0:
  * New features:
    + New Django samples. (#636)
    + Add support for RFC7636 PKCE. (#588)
    + Release as a universal wheel. (#665)
  * Bug fixes:
    + Fix django authorization redirect by correctly checking validity
    of credentials. (#651)
    + Correct query loss when using parse_qsl to dict. (#622)
    + Switch django models from pickle to jsonpickle. (#614)
    + Support new MIDDLEWARE Django 1.10 aetting. (#623)
    + Remove usage of os.environ.setdefault. (#621)
    + Handle missing storage files correctly. (#576)
    + Try to revoke token with POST when getting a 405. (#662)
  * Internal changes:
    + Use transport module for GCE environment check. (#612)
    + Remove author lines and add contributors.md. (#627)
    + Clean up imports. (#625)
    + Use transport.request in tests. (#607)
    + Drop unittest2 dependency (#610)
    + Remove backslash line continuations. (#608)
    + Use transport helpers in system tests. (#606)
    + Clean up usage of HTTP mocks in tests. (#605)
    + Remove all uses of MagicMock. (#598)
    + Migrate test runner to pytest. (#569)
    + Merge util.py and _helpers.py. (#579)
    + Remove httplib2 imports from non-transport modules. (#577)
  * Breaking changes:
    + Drop Python 3.3 support. (#603)
    + Drop Python 2.6 support. (#590)
    + Remove multistore_file. (#589)
* Wed Oct 12 2016 rjschwei@suse.com
- Add missing dependency on python-fasteners
* Wed Oct  5 2016 rjschwei@suse.com
- Update to version 3.0.0 (bsc#1002895)
  + Add patch oauth2client-init-django-settings.patch (#661)
  + Package tests again, but remain disabled due to Django issue (#661)
  + Populate token_expiry for GCE credentials. (#473)
  + Move GCE metadata interface to a separate module. (#520)
  + Populate scopes for GCE credentials. (#524)
  + Fix Python 3.5 compatibility. (#531)
  + Add oauth2client.contrib.sqlalchemy, a SQLAlchemy-based credential
    store. (#527)
  + Improve error when an invalid client secret is provided. (#530)
  + Add oauth2client.contrib.multiprocess_storage. This supersedes the
    functionality in oauth2client.contrib.multistore_file. (#504)
  + Pull httplib2 usage into a separate transport module. (#559, #561)
  + Refactor all django-related code into oauth2client.contrib.django_util.
    Add DjangoORMStorage, remove FlowField. (#546)
  + Fix application default credentials resolution order. (#570)
  + Add configurable timeout for GCE metadata server check. (#571)
  + Add warnings when using deprecated approval_prompt='force'. (#572)
  + Add deprecation warning to oauth2client.contrib.multistore_file. (#574)
  + (Hygiene) PEP8 compliance and various style fixes (#537, #540, #552, #562)
  + (Hygiene) Remove duplicated exception classes in
    oauth2client.contrib.appengine. (#533)
- From 2.2.0
  + Added support to override token_uri and revoke_uri in
    oauth2client.service_account.ServiceAccountCredentials. (#510)
  + oauth2client.contrib.multistore_file now handles OSError in addition
    to IOError because Windows may raise OSError where other platforms
    will raise IOError.
  + oauth2client.contrib.django_util and oauth2client.contrib.django_orm
    have been updated to support Django 1.8 - 1.10. Versions of Django
    below 1.8 will not work with these modules.
- From 2.1.0
  + Add basic support for JWT access credentials. (#503)
  + Fix oauth2client.client.DeviceFlowInfo to use UTC instead of the
    system timezone when calculating code expiration.
- From 2.0.2
  + Fix issue where flask_util.UserOAuth2.required would accept expired
    credentials (#452).
  + Fix issue where flask_util would fill the session with Flow objects (#498).
  + Fix issue with Python 3 binary strings in Flow.step2_exchange (#446).
  + Improve test coverage to 100%%.
* Fri Mar 11 2016 tbechtold@suse.com
- update to 2.0.1:
  * Making scopes optional on Google Compute Engine `AppAssertionCredentials`
    and adding a warning that GCE won't honor scopes (#419)
  * Adding common `sign_blob()` to service account types and a
    `service_account_email` property. (#421)
  * Improving error message in P12 factory
    `ServiceAccountCredentials.from_p12_keyfile` when pyOpenSSL is
    missing. (#424)
  * Allowing default flags in `oauth2client.tools.run_flow()`
    rather than forcing users to create a dummy argparser (#426)
  * Removing `oauth2client.util.dict_to_tuple_key()` from public
    interface (#429)
  * Adding `oauth2client.contrib._appengine_ndb` helper module
    for `oauth2client.contrib.appengine` and moving most code that
    uses the `ndb` library into the helper (#434)
  * Fix error in `django_util` sample code (#438)
  * Fix Google Compute Engine breakage (#411, breakage introduced in #387) that
    made it impossible to obtain access tokens
  * Implement `ServiceAccountCredentials.from_p12_keyfile_buffer()`
    to allow passing a file-like object in addition to the factory
    constructor that uses a filename directly (#413)
  * Implement `ServiceAccountCredentials.create_delegated()`
    to allow upgrading a credential to one that acts on behalf
    of a given subject (#420)
  * Add django_util (#332)
  * Avoid OAuth2Credentials `id_token` going out of sync after a token
    refresh (#337)
  * Move to a `contrib` sub-package code not considered a core part of
    the library (#346, #353, #370, #375, #376, #382)
  * Add `token_expiry` to `devshell` credentials (#372)
  * Move `Storage` locking into a base class (#379)
  * Added dictionary storage (#380)
  * Added `to_json` and `from_json` methods to all `Credentials`
    classes (#385)
  * Fall back to read-only credentials on EACCES errors (#389)
  * Coalesced the two `ServiceAccountCredentials`
    classes (#395, #396, #397, #398, #400)
  * Add access token refresh error class that includes HTTP status (#310)
  * Python3 compatibility fixes for Django (#316, #318)
  * Fix incremental auth in flask_util (#322)
  * Fall back to credential refresh on EDEADLK in multistore_file (#336)
- Remove test package. tests are no longer shipped by upstream.
- Remove hidePythonDeps.patch
- Some imports moved from oauth2client to oauth2client.contrib
* Sat Jan  2 2016 rjschwei@suse.com
- Do not build the -django subpackage on SLE 12 in IBS
  + libwebp in SLE 12 is too old nad has issues on s390x. libwebp is a
    dependency for python-Pillow, which in turn is a dependncy for
    python-Django
  + .changes file changes in OBS only as we have access to fixed libwebp
    for SLE 12
* Tue Dec  1 2015 rjschwei@suse.com
- Remove -django subpackage requirements for SLE 11
* Tue Dec  1 2015 rjschwei@suse.com
- Do not build the -django subpackage on SLE 11
  + The latest version of Django no longer builds on SLE 11, Python
    is too old
* Tue Dec  1 2015 rjschwei@suse.com
- Include in SLE 12 (FATE#319904, bsc#954690)
* Sat Nov 21 2015 rjschwei@suse.com
- Initial build
  + Version 1.5.1
